@@ -68,10 +68,6 @@ class WrongNameException(DeviceException):
     """ is raised when no connection with a given name could be found.
     """
     pass
-class NotReadyException(DeviceException):
-    """ is raised when no connection was able to establish a connection to the device
-    """
-    pass
 
 
 ##############################
@@ -136,17 +132,6 @@ class Device(object):
                     msg,
         ))
 
-    def wait_for_ready(self):
-        self.log("wait for system ready")
-        for c in self.conns:
-            try:
-                self.log("wait for prompt on connection " + str(c.name))
-                c.wait_for_prompt()
-                self.log("ready")
-                return
-            except conn.NoPromptException as e:
-                self.log("Timeout Exceeded, try next connection")
-        raise NotReadyException("No connection was able to successfully wait for a prompt")
     def get_conn(self, which):
         self.log("get_conn({})".format(which))
         try:
@@ -245,7 +230,7 @@ class Hydra(Device):
     def has_newest_firmware(self):
         """ check whether the installed firmware is the newest on jenkins
         """
-        return self.latest_build in self.current_fw_version
+        return str(self.latest_build) in str(self.current_fw_version)
 
     @property
     def is_updated(self):
